@@ -1,7 +1,7 @@
 package AUBBC;
 =head1 COPYLEFT
 
- AUBBC.pm, v1.10 09/02/2008 09:49:46 By: N.K.A
+ AUBBC.pm, v1.20 09/07/2008 09:23:09 By: N.K.A
 
  Advanced Universal Bulletin Board Code Tags.
 
@@ -14,7 +14,7 @@ use warnings;
 
 our ( $DEBUG_AUBBC, $BAD_MESSAGE, %SMILEYS ) = ( '', 'Error', () );
 
-my ( $AUBBC_VERSION, %Build_AUBBC ) = ( '1.10', () );
+my ( $AUBBC_VERSION, %Build_AUBBC ) = ( '1.20', () );
 
 my %AUBBC = (
 aubbc => 1,
@@ -102,29 +102,29 @@ my ($self,$name) = @_;
 sub code_highlight {
     my $text_code = shift;
     warn "START code_highlight" if $DEBUG_AUBBC;
-    $text_code =~ s~<br>~=br=~gso;
+    $text_code =~ s~<br$AUBBC{html_type}>~=br$AUBBC{html_type}=~gso;
     $text_code =~ s!:!&#58;!go;
     $text_code =~ s!\[!&#91;!go;
     $text_code =~ s!\]!&#93;!go;
     $text_code =~ s!\{!&#123;!go;
     $text_code =~ s!\}!&#125;!go;
     $text_code =~ s!%!&#37;!go;
-    $text_code =~ s!\s{1};!&#59;!go; # ;
+    $text_code =~ s!\s{1};! &#59;!go; # ;
     $text_code =~ s{&lt;}{&#60;}go;
     $text_code =~ s{&gt;}{&#62;}go;
     $text_code =~ s{&quot;}{&#34;}go;
 if ($AUBBC{highlight}) {
     warn "START block highlight" if $DEBUG_AUBBC;
-    $text_code =~ s{\z}{=br=}go if $text_code !~ m/=br=\z/io; # fix
+    $text_code =~ s{\z}{=br$AUBBC{html_type}=}go if $text_code !~ m/=br$AUBBC{html_type}=\z/io; # fix
     $text_code =~ s!(&#60;&#60;(\w+);.*?\b\2\b)!<font color=DarkRed>$1</font>!go;
-    $text_code =~ s{(?<![\&\$])(\#.*?(?:=br=))}{<font color='#0000FF'><i>$1</i></font>}igo;
-    $text_code =~ s{(&#39;.*?(?:&#39;|=br=))}{<font color='#8B0000'>$1</font>}go;
-    $text_code =~ s{(&#34;.*?(?:&#34;|=br=))}{<font color='#8B0000'>$1</font>}go;
+    $text_code =~ s{(?<![\&\$])(\#.*?(?:=br$AUBBC{html_type}=))}{<font color='#0000FF'><i>$1</i></font>}igo;
+    $text_code =~ s{(&#39;.*?(?:&#39;|=br$AUBBC{html_type}=))}{<font color='#8B0000'>$1</font>}go;
+    $text_code =~ s{(&#34;.*?(?:&#34;|=br$AUBBC{html_type}=))}{<font color='#8B0000'>$1</font>}go;
     $text_code =~ s{(?<![\#|\w|\d])(\d+)(?!\w)}{<font color='#008000'>$1</font>}go;
     $text_code =~ s!\b(strict|package|return|require|for|my|sub|if|eq|ne|lt|ge|le|gt|or|use|while|foreach|next|last|unless|elsif|else|not|and|until|continue|do|goto)\b!<b>$1</b>!go;
     warn "END block highlight" if $DEBUG_AUBBC;
     }
-    $text_code =~ s~=br=~<br>~gso;
+    $text_code =~ s~=br$AUBBC{html_type}=~<br$AUBBC{html_type}>~gso;
     warn "END code_highlight" if $DEBUG_AUBBC;
     return $text_code;
 }
@@ -142,7 +142,7 @@ sub do_ubbc {
           }isg;
         # [code=...]...[/code] or [c=...]...[/c]
         $message =~ s{\[(?:c|code)=(.+?)\](?s)(.+?)\[/(?:c|code)\]} {
-         $1:<br>
+         $1:<br$AUBBC{html_type}>
           <div$AUBBC{code_class}><code>
           ${\code_highlight($2)}
           </code></div>$AUBBC{code_extra}
@@ -185,7 +185,7 @@ sub do_ubbc {
               }
 
         $message =~ s~\[color=([\w#]+)\](.*?)\[/color\]~<font color='$1'>$2</font>~isgo;
-        $message =~ s~\[quote=([\w\s]+)\]~<span$AUBBC{quote_class}><small><b><u>$1:</u></b></small><br>~isgo;
+        $message =~ s~\[quote=([\w\s]+)\]~<span$AUBBC{quote_class}><small><b><u>$1:</u></b></small><br$AUBBC{html_type}>~isgo;
         $message =~ s~\[/quote\]~</span>$AUBBC{quote_extra}~isgo;
         $message =~ s~\[quote\]~<span$AUBBC{quote_class}>~isgo;
         $message =~ s~\[right\]~<div align=\"right\">~isgo;
@@ -399,11 +399,11 @@ sub do_unicode {
     warn "ENTER do_unicode $self" if $DEBUG_AUBBC;
     # Unicode Support
     # [utf://x23]
-    $message =~ s{\[utf://(x?[0-9a-f]+)\]}{&#$1\;}igso;
+    $message =~ s{\[utf://(x?[0-9a-f]+)\]}{&#$1;}igso;
     # &#x23; or &#0931;
-    $message =~ s{&amp\;#(x?[0-9a-f]+)\;}{&#$1\;}igso;
+    $message =~ s{&amp;#(x?[0-9a-f]+);}{&#$1;}igso;
     # code names
-    $message =~ s{&amp\;([a-fA-Z]+)\;}{&$1\;}igso;
+    $message =~ s{&amp;([a-fA-Z]+);}{&$1;}igso;
     warn "END do_unicode $self" if $DEBUG_AUBBC;
     return $message;
 }
@@ -432,12 +432,11 @@ sub do_all_ubbc {
     warn "ENTER do_all_ubbc $self" if $DEBUG_AUBBC;
     if (!$AUBBC{no_bypass} && $message =~ s/\A\#none//go) {
         warn "START&END no_bypass $self" if $DEBUG_AUBBC;
-        $message = $self->script_escape($message) if $AUBBC{script_escape}; # Added
+        $message = $self->script_escape($message) if $AUBBC{script_escape};
          return $message;
     }
      else {
-    $message = $self->script_escape($message) if $AUBBC{script_escape}; # Moved up here
-    return $message unless $message =~ m{[\[\]\(\:]};
+    $message = $self->script_escape($message) if $AUBBC{script_escape};
     $message = $self->escape_aubbc($message, 1) if $AUBBC{aubbc_escape};
     $message = (!$AUBBC{no_bypass} && $message =~ s/\A\#noubbc//go)
         ? $message
@@ -497,7 +496,7 @@ warn "ENTER html_escape $self" if $DEBUG_AUBBC;
         $text =~ s{\\}{&#92;}gso;
         $text =~ s{\|}{&#124;}gso;
         }
-        $text =~ s{\n}{<br>}gso if (!$option);
+        $text =~ s{\n}{<br$AUBBC{html_type}>}gso if (!$option);
         $text =~ s{\cM}{}gso if ($option || !$option);
 warn "END html_escape $self" if $DEBUG_AUBBC;
         return $text;
@@ -521,7 +520,7 @@ warn "ENTER html_to_text $self" if $DEBUG_AUBBC;
         $html =~ s{&#92;}{\\}gso;
         $html =~ s{&#124;}{\|}gso;
         }
-        $html =~ s{<br>}{\n}gso if (!$option);
+        $html =~ s{<br$AUBBC{html_type}>}{\n}gso if (!$option);
 warn "END html_to_text $self" if $DEBUG_AUBBC;
         return $html;
 }
